@@ -4,6 +4,7 @@ import pytest
 from mock import Mock, patch
 
 import vessl
+from test.conftest import USE_MOCK
 from vessl.util.config import VesslConfigLoader
 from vessl.util.constant import (
     ACCESS_TOKEN_ENV_VAR,
@@ -17,8 +18,6 @@ from vessl.util.exception import (
     VesslApiException,
 )
 
-from test.conftest import USE_MOCK  # isort:skip
-
 config_path_api = "test/config_api"
 
 
