@@ -1,11 +1,11 @@
 import os
-from test.conftest import USE_MOCK
-from test.util import random_string
 
 import pytest
 from Crypto.PublicKey import RSA
 
 import vessl
+from test.conftest import USE_MOCK
+from vessl.util.random import random_string
 
 
 @pytest.mark.skipif(USE_MOCK, reason="Does not run if mocking is used.")
