@@ -188,7 +188,6 @@ def upload(name: str, source: str, dest: str):
         source_path=source,
         dest_path=dest,
     )
-    print(f"Uploaded {source} to {dest}.")
 
 
 @cli.vessl_command()
@@ -215,7 +214,6 @@ def download(name: str, source: str, dest: str):
         source_path=source,
         dest_path=dest,
     )
-    print(f"Downloaded {source} to {dest}.")
 
 
 @cli.vessl_command()
