@@ -36,6 +36,7 @@ from vessl.kernel_image import list_kernel_images
 from vessl.util import logger
 from vessl.util.common import safe_cast
 from vessl.util.constant import (
+    EXPERIMENT_WORKING_DIR,
     FRAMEWORK_TYPE_PYTORCH,
     FRAMEWORK_TYPE_TENSORFLOW,
     FRAMEWORK_TYPES,
@@ -409,7 +410,7 @@ git_ref_option = click.option(
     "--git-ref",
     type=click.STRING,
     multiple=True,
-    help="Git repository mounts. Format: [mount_path]:github/[organization]/[repository]/[optional_commit], ex. `--git-ref /home/vessl/examples:github/savvihub/examples/3cd23dd`.",
+    help=f"Git repository mounts. Format: [mount_path]:github/[organization]/[repository]/[optional_commit], ex. `--git-ref {EXPERIMENT_WORKING_DIR}examples:github/vessl-ai/examples/3cd23dd`.",
 )
 git_diff_option = click.option(
     "--git-diff",
@@ -435,7 +436,7 @@ archive_file_option = click.option(
 )
 root_volume_size_option = click.option("--root-volume-size", type=click.STRING)
 working_dir_option = click.option(
-    "--working-dir", type=click.STRING, help="Defaults to `/home/vessl/`."
+    "--working-dir", type=click.STRING, help=f"Defaults to `{EXPERIMENT_WORKING_DIR}`."
 )
 output_dir_option = click.option(
     "--output-dir",
