@@ -354,11 +354,6 @@ def backup():
 
 
 @cli.vessl_command()
-@vessl_option(
-    "--workspace-id",
-    type=click.INT,
-    help="Workspace id to restore.",
-)
 @organization_name_option
-def restore(workspace_id: int):
-    restore_workspace(workspace_id)
+def restore():
+    restore_workspace()
