@@ -13,7 +13,7 @@ from vessl import vessl_api
 from vessl.organization import _get_organization_name
 from vessl.util.constant import DATASET_PATH_SCHEME_GS, DATASET_PATH_SCHEME_S3
 from vessl.util.exception import InvalidDatasetError
-from vessl.volume import copy_volume_file, delete_volume_file, list_volume_files
+from vessl.volume import copy_volume_file, delete_volume_file, list_volume_files, _copy_volume_file_remote_to_local
 
 
 def read_dataset(dataset_name: str, **kwargs) -> ResponseDatasetInfoDetail:
@@ -299,12 +299,21 @@ def download_dataset_volume_file(
         ```
     """
     dataset = read_dataset(dataset_name, **kwargs)
-    return copy_volume_file(
-        source_volume_id=dataset.volume_id,
-        source_path=source_path,
-        dest_volume_id=None,
-        dest_path=dest_path,
-    )
+    if dataset.source.provider == "s3":
+        return copy_volume_file(
+            source_volume_id=dataset.volume_id,
+            source_path=source_path,
+            dest_volume_id=None,
+            dest_path=dest_path,
+        )
+    elif dataset.source.provider == "gs":
+        return _copy_volume_file_remote_to_local(
+            dataset.volume_id,
+            source_path,
+            dest_path,
+        )
+    else:
+        print("Cannot download from on-premise dataset.")
 
 
 def copy_dataset_volume_file(
