@@ -274,7 +274,7 @@ class VesslRun(object):
             self.hyperparameters.configure(self.api, self._experiment)
 
             print(
-                f"Connected to {self._experiment.number}.\n"
+                f"Connected to experiment #{self._experiment.number}.\n"
                 f"For more info: {Endpoint.experiment.format(self._experiment.organization.name, self._experiment.project.name, self._experiment.number)}"
             )
 
@@ -292,6 +292,12 @@ class VesslRun(object):
             self._sender = Sender(self.api, self._experiment.id, collectors)
             self._start()
 
+        elif self._mode == MODE_LOCAL:
+            print(
+                f"Already connected to experiment #{self._experiment.number}.\n"
+                "To start a new experiment, call `vessl.finish()` first and `vessl.init()` again."
+            )
+
         if self._mode == MODE_MANAGED:
             if hp is None:
                 return
