@@ -47,16 +47,16 @@ class RunnerBase(abc.ABC):
 
     This base class introduces 5 static methods as followings:
     - `predict`: Make prediction with given data and model. This method must be overridden. The
-        data is given from the result of `preprocess_data`, and the return value of this method
-        will be passed to `postprocess_data` before serving.
+      data is given from the result of `preprocess_data`, and the return value of this method
+      will be passed to `postprocess_data` before serving.
     - `save_model`: Save the model into a file. Return value of this method will be given to the
-        `load_model` method on model loading. If this method is overriden, `load_model` must be
-        overriden as well.
+      `load_model` method on model loading. If this method is overriden, `load_model` must be
+      overriden as well.
     - `load_model`: Load the model from a file.
     - `preprocess_data`: Preprocess the data before prediction. It converts the API input data to
-        the model input data.
+      the model input data.
     - `postprocess_data`: Postprocess the data after prediction. It converts the model output data
-        to the API output data.
+      to the API output data.
 
     Check each method's docstring for more information.
     """
@@ -482,26 +482,34 @@ def register_model(
     artifacts: Dict[str, str] = None,
     **kwargs,
 ):
-    """Register the given model for serving. If you want to override the default organization, then pass `organization_name` as `**kwargs`.
+    """Register the given model for serving. If you want to override the
+    default organization, then pass `organization_name` as `**kwargs`.
 
     Args:
         repository_name(str): Model repository name.
-        model_number(int | None): Model number. If None, new model will be created. In such case, `model_instance` must be given.
+        model_number(int | None): Model number. If None, new model will be
+            created. In such case, `model_instance` must be given.
         runner_cls(RunnerBase): Runner class that includes code for serving.
-        model_instance(ModelType | None): Model instance. If None, `runner_cls` must override `load_model` method. Defaults to None.
-        requirements(List[str]): Python requirements for the model. Defaults to [].
-        artifacts(Dict[str, str]): Artifacts to be uploaded. Key is the path to artifact in local filesystem, and value is the
-            path in the model volume. Only trailing asterisk(*) is allowed for glob pattern. Defaults to {}.
+        model_instance(ModelType | None): Model instance. If None, `runner_cls`
+            must override `load_model` method. Defaults to None.
+        requirements(List[str]): Python requirements for the model. Defaults to
+            [].
+        artifacts(Dict[str, str]): Artifacts to be uploaded. Key is the path to
+            artifact in local filesystem, and value is the path in the model
+            volume. Only trailing asterisk(*) is allowed for glob pattern.
+            Defaults to {}.
 
     Example:
-        >>> register_model(
-        >>>     repository_name="my-model",
-        >>>     model_number=1,
-        >>>     runner_cls=MyRunner,
-        >>>     model_instance=model_instance,
-        >>>     requirements=["torch", "torchvision"],
-        >>>     artifacts={"model.pt": "model.pt", "checkpoints/*": "checkpoints/*"},
-        >>> )
+        ```python
+        register_model(
+            repository_name="my-model",
+            model_number=1,
+            runner_cls=MyRunner,
+            model_instance=model_instance,
+            requirements=["torch", "torchvision"],
+            artifacts={"model.pt": "model.pt", "checkpoints/*": "checkpoints/*"},
+        )
+        ```
     """
     organization_name = _get_organization_name(**kwargs)
     if requirements is None:
@@ -529,15 +537,32 @@ def register_torch_model(
     requirements: List[str] = None,
     **kwargs,
 ):
-    """Register the given torch model instance for model serving. If you want to override the default organization, then pass `organization_name` as `**kwargs`.
+    """Register the given torch model instance for model serving. If you want to
+    override the default organization, then pass `organization_name` as
+    `**kwargs`.
 
     Args:
         repository_name(str): Model repository name.
-        model_number(int | None): Model number. If None, new model will be created.
+        model_number(int | None): Model number. If None, new model will be
+            created.
         model_instance(model_instance): Torch model instance.
-        preprocess_data(callable): Function that will preprocess data. Defaults to identity function.
-        postprocess_data(callable): Function that will postprocess data. Defaults to identity function.
+        preprocess_data(callable): Function that will preprocess data.
+            Defaults to identity function.
+        postprocess_data(callable): Function that will postprocess data.
+            Defaults to identity function.
         requirements(list): List of requirements. Defaults to [].
+
+    Example:
+        ```python
+        vessl.register_model(
+            repository_name="my-model",
+            model_number=1,
+            model_instance=model_instance,
+            preprocess_data=lambda x: int(x),
+            postprocess_data=lambda x: {"prediction": x},
+            requirements=["torch", "torchvision"],
+        )
+        ```
     """
     # Check if the model is torch
     torch_nn = get_module(
