@@ -42,3 +42,9 @@ def is_processor_m1():
     from cpuinfo import get_cpu_info
 
     return "m1" in get_cpu_info().get("brand_raw").lower()
+
+
+def remove_prefix(text, prefix):
+    if text.startswith(prefix):
+        return text[len(prefix):]
+    return text
