@@ -4,6 +4,7 @@ from concurrent.futures import Future
 from requests_futures.sessions import FuturesSession
 
 from openapi_client import StorageFile
+from vessl.util.common import remove_prefix
 from vessl.util.file_transmission import (
     FileTransmissionHandler,
     FileTransmissionTracker,
@@ -31,17 +32,11 @@ class Downloader:
                 dest_path, remote_files[0].download_url.url, remote_files[0].size
             )
         else:
-            dir_exists = os.path.exists(dest_path)
             for file in remote_files:
-                if dir_exists:
-                    # create subdirectory
-                    dir_name = os.path.basename(os.path.dirname(file.path))
-                    file_name = os.path.basename(file.path)
-                    local_full_path = os.path.join(dest_path, dir_name, file_name)
-                else:
-                    local_full_path = os.path.join(
-                        dest_path, os.path.basename(file.path)
-                    )
+                file_path = remove_prefix(file.path, source_path).lstrip("/")
+                dir_name = os.path.dirname(file_path)
+                file_name = os.path.basename(file_path)
+                local_full_path = os.path.join(dest_path, dir_name, file_name)
                 handler.add_file(local_full_path, file.download_url.url, file.size)
 
         handler.run()
