@@ -40,6 +40,7 @@ from vessl.util.git_local import get_git_diff_path, get_git_ref, get_git_repo
 from vessl.util.random import random_string
 from vessl.util.tar import Tar
 from vessl.util.uploader import Uploader
+from vessl.util.volume import VolumeFileTransfer
 
 
 def read_volume_file(volume_id: int, path: str) -> StorageFile:
@@ -200,19 +201,12 @@ def copy_volume_file(
         ```
     """
     if source_volume_id is None and dest_volume_id:
-        return _copy_volume_file_local_to_remote(
-            source_path,
-            dest_volume_id,
-            dest_path,
-        )
+        VolumeFileTransfer(dest_volume_id).upload(source_path, dest_path)
+        return
 
     if dest_volume_id is None and source_volume_id:
-        return _copy_volume_file_remote_to_local(
-            source_volume_id,
-            source_path,
-            dest_path,
-            quiet,
-        )
+        VolumeFileTransfer(source_volume_id).download(source_path, dest_path)
+        return
 
     if source_volume_id and dest_volume_id:
         return _copy_volume_file_remote_to_remote(
